==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WrapperExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
/**
 * @hidden
 */
export let WrapperExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WrapperExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WrapperExpressionDescriptionMetadata.a == null) {
                WrapperExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WrapperExpressionDescriptionMetadata.c(WrapperExpressionDescriptionMetadata.a);
            }
            if (a.j(WrapperExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(WrapperExpressionDescriptionMetadata.a);
            FilterExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("InnerExpression", "ExportedType:IFilterExpression");
            a.item("Expression", "ExportedType:FilterExpression");
            a.item("PropertyName", "String");
        }
        static d(a) {
            WrapperExpressionDescriptionMetadata.b(a);
            a.z("WrapperExpression", WrapperExpressionDescriptionMetadata.a);
        }
    }
    WrapperExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WrapperExpressionDescriptionMetadata, 'WrapperExpressionDescriptionMetadata');
    WrapperExpressionDescriptionMetadata.a = null;
    return WrapperExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WrapperExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
/**
 * @hidden
 */
export let WrapperExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WrapperExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WrapperExpressionDescriptionMetadata.a == null) {
                WrapperExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WrapperExpressionDescriptionMetadata.c(WrapperExpressionDescriptionMetadata.a);
            }
            if (a.k(WrapperExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WrapperExpressionDescriptionMetadata.a);
            FilterExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("InnerExpression", "ExportedType:IFilterExpression");
            a.item("Expression", "ExportedType:FilterExpression");
            a.item("PropertyName", "String");
        }
        static d(a) {
            WrapperExpressionDescriptionMetadata.b(a);
            a.ab("WrapperExpression", WrapperExpressionDescriptionMetadata.a);
        }
    }
    WrapperExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WrapperExpressionDescriptionMetadata, 'WrapperExpressionDescriptionMetadata');
    WrapperExpressionDescriptionMetadata.a = null;
    return WrapperExpressionDescriptionMetadata;
})();
